@@ -34,6 +34,7 @@ from typing import Optional
 
 import pytest
 from selenium import webdriver
+from selenium.webdriver.common.by import By
 from utils import get_portal_tile, keycloak_login, keycloak_password_change, wait_for_class, wait_for_id
 
 from univention.appcenter.actions import get_action
@@ -177,7 +178,8 @@ def portal_config(ucr: ConfigRegistry) -> SimpleNamespace:
 
 @pytest.fixture()
 def keycloak_config(ucr: ConfigRegistry) -> SimpleNamespace:
-    url = f"https://ucs-sso-ng.{ucr['domainname']}"
+    server = ucr.get("keycloak/server/sso/fqdn", f"ucs-sso-ng.{ucr['domainname']}")
+    url = f"https://{server}"
     config = {
         "url": url,
         "admin_url": f"{url}/admin",
@@ -276,7 +278,7 @@ def keycloak_adm_login(selenium: webdriver.Chrome, keycloak_config: SimpleNamesp
         wait_for_class(selenium, keycloak_config.admin_console_class)
         assert selenium.title == keycloak_config.title
         admin_console = wait_for_class(selenium, keycloak_config.admin_console_class)[0]
-        admin_console.find_element_by_tag_name("a").click()
+        admin_console.find_element(By.TAG_NAME, "a").click()
         keycloak_login(selenium, keycloak_config, username, password, fails_with=fails_with)
         if fails_with:
             return selenium
